History
=======

v0.4.5 (2019-10-24)
-------------------
- FIXED #9: Wrong stress for some Menq components.

v0.4.4 (2019-05-22)
-------------------
-  Incremented version because of issue with automated builds.

v0.4.3 (2019-05-22)
-------------------
-  FIXED: Bug in MANIFEST.in

v0.4.2 (2019-05-22)
-------------------
-  Incremented version because of issue with automated builds.

v0.4.1 (2019-05-22)
-------------------
-  Fixed strain profile to use ``max_strain``.
-  Changed README and HISTORY to markdown.

v0.4.0 (2019-03-11)
-------------------
-  Added smoothed FourierAmplitudeSpectrum output.

v0.3.2 (2018-12-02)
-------------------
-  Fixed building of docs.
-  Removed stickler.
-  Version double increment due to pypi naming conflict.

v0.3.0 (2018-11-30)
-------------------
-  Converted all damping to decimal.
-  Added tests for KishidaSoilType.
-  Added tests against Deepsoil.

v0.0.1 (2016-04-30)
-------------------
-  First release on PyPI.
